Generate area-proportional Euler diagrams using numerical optimization. A Euler diagram is a generalization of a Venn diagram, relaxing the criterion that all interactions need to be represented. Diagrams may be fit with circles, ellipses, squares, and rectangles via a wide range of inputs and can be visualized in numerous ways.
Author
Maintainer: Johan Larsson johan@jolars.co (ORCID) [copyright holder]
Authors:
Johan Larsson johan@jolars.co (ORCID) [copyright holder]
Other contributors:
A. Jonathan R. Godfrey [contributor]
Peter Gustafsson [contributor]
David H. Eberly (geometric algorithms) [contributor]
Emanuel Huber (root solver code) [contributor]
Florian Privé [contributor]