Fitted values of euler object
Usage
# S3 method for class 'euler'
fitted(object, dense = FALSE, ...)Arguments
- object
object of class
'euler'- dense
if
TRUE, return a vector covering every combination of the non-empty sets (2^n - 1entries), filling absent combinations with 0. The default (FALSE) returns the sparse vector stored on the object, which only contains entries that were either requested as input or fit to a non-zero area. Usedense = TRUEonly for diagrams with few sets — the full enumeration is exponential in the number of non-empty sets.- ...
ignored