max_sets_default: Default number of sets that 'eunoia' accepts before rejecting...

View source: R/extendr-wrappers.R

max_sets_defaultR Documentation

Default number of sets that eunoia accepts before rejecting a spec. Used by the R-side input validator so the cap is not hardcoded.

Description

Default number of sets that eunoia accepts before rejecting a spec. Used by the R-side input validator so the cap is not hardcoded.

Usage

max_sets_default()

eulerr documentation built on May 30, 2026, 1:07 a.m.