max_sets_hard_cap: Absolute upper bound on the number of sets that 'eunoia' can...

View source: R/extendr-wrappers.R

max_sets_hard_capR Documentation

Absolute upper bound on the number of sets that eunoia can represent in a single diagram. Used by the R-side input validator so the cap is not hardcoded.

Description

Absolute upper bound on the number of sets that eunoia can represent in a single diagram. Used by the R-side input validator so the cap is not hardcoded.

Usage

max_sets_hard_cap()

eulerr documentation built on May 30, 2026, 1:07 a.m.