Panel Function for Euler Circles (deprecated)
panel.euler.circles(x, y, r, border, fill, fill_alpha, ...,
identifier, name.type, col, font, fontface)X coordinates for the centers.
Y coordinates for the centers.
Radius of the circle
Border color.
Circle fill.
Fill opacity
Passed on to grid::grid.circle().
Ignored
Ignored
Ignored
A character string that is prepended to the name of the grob that is created.
A character value indicating whether the name of the grob
should have panel or strip information added to it. Typically either
"panel", "strip", "strip.left", or "" (for no extra information).
Plots circles inside a trellis panel.