This function is responsible for printing objects from
from venn() and provides a simple description of the number of
sets and the specifications for the ellipses of the Venn diagram.
Arguments
- x
an object of class
'eulerr_venn'- round
number of digits to round the ellipse specification to
- vsep
character string to paste in between
eulerobjects whenxis a nestedeulerobject- ...
arguments passed to
base::print.data.frame()
Examples
venn(organisms)
#> 5 set Venn diagram
#>
#> type h k a b phi width height side
#> animal ellipse 0.176 0.096 1 0.6 0.000 NA NA NA
#> mammal ellipse -0.037 0.197 1 0.6 1.257 NA NA NA
#> plant ellipse -0.198 0.026 1 0.6 2.513 NA NA NA
#> sea ellipse -0.086 -0.181 1 0.6 3.770 NA NA NA
#> spiny ellipse 0.145 -0.137 1 0.6 5.027 NA NA NA