| setup_grobs | R Documentation |
Grobify Euler objects
setup_grobs(
x,
fills,
patterns,
edges,
labels,
set_labels = NULL,
quantities,
annotations = NULL,
glyphs = NULL,
complement = NULL,
number,
merged_sets,
n_vertices = 200L,
placement_opts = NULL,
combo_labels = NULL
)
x |
geometry data |
fills |
fills params |
patterns |
pattern params |
edges |
edges params |
labels |
labels params |
set_labels |
exterior set-label params |
quantities |
quantities params |
annotations |
annotations params |
glyphs |
glyph params |
complement |
complement label params |
number |
current diagram number |
merged_sets |
sets that are the same and have been merged |
n_vertices |
number of vertices used to render each shape |
placement_opts |
label placement options, or |
combo_labels |
region labels in the order of the per-region graphical
parameters ( |
A grid::gList() is returned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.