Skip to contents

This function provides a means to set default parameters for functions in eulerr. Query eulerr_options() (without any argument) to see all the available options and read more about the plot-related ones in grid::gpar() and graphics::par().

Usage

eulerr_options(...)

Arguments

...

objects to update the global graphical parameters for eulerr with.

Value

This function gets or sets updates in the global environment that are used in plot.euler().

Details

Currently, the following items will be considered:

pointsize

size in pts to be used as basis for fontsizes and some margin sizes in the resulting plot

#'
fills

a list of items fill and alpha

patterns

a list of items type, angle, col, lwd, and alpha

edges

a list of items col, alpha, lex, lwd, and lty

labels

a list of items rot, col, alpha, fontsize, cex, fontfamily, fontface, lineheight, and font

quantities

a list of items type, template, format, total, rot, col, alpha, fontsize, cex, fontfamily, lineheight, and font

annotations

a list of items rot, col, alpha, fontsize, cex, fontfamily, lineheight, font, and labels (a named character vector keyed by subset name). Used to add a third stacked text element per region below the quantity.

strips

col, alpha, fontsize, cex, fontfamily, lineheight, and font

legend

arguments to grid::legendGrob() as well as col, alpha, fontsize, cex, symbol_size (symbol size multiplier, independent of text size; defaults to cex if NULL), fontfamily, lineheight, and font

main

arguments to grid::textGrob()

complement

a list of styling defaults for the container box and its complement label drawn when euler() is called with complement =. Items: fill, alpha, col, lty, lwd, lex, fontsize, cex, font, fontfamily, lineheight. The default lty = 2 draws the container with a dashed outline.

padding

a grid::unit() giving the padding between various elements in plots from plot.euler(), which you can change if you, for instance, want to increase spacing between labels, quantities, and percentages.

composition

a list controlling how eulergram objects are arranged when composed via | or /. Contains a single spacing item (a grid::unit()) that sets the gap between adjacent plots.

Examples

eulerr_options(edges = list(col = "blue"), fontsize = 10)
eulerr_options(n_threads = 2)