This function provides a means to set default parameters for functions
in eulerr. Query eulerr_options() (without any
argument) to see all the available options and read more about
the plot-related ones in grid::gpar() and graphics::par().
Value
This function gets or sets updates in the global environment
that are used in plot.euler().
Details
Currently, the following items will be considered:
- pointsize
size in pts to be used as basis for fontsizes and some margin sizes in the resulting plot
#'
- fills
a list of items
fillandalpha- patterns
a list of items
type,angle,col,lwd, andalpha- edges
a list of items
col,alpha,lex,lwd, andlty- labels
a list of items
rot,col,alpha,fontsize,cex,fontfamily,fontface,lineheight, andfont- quantities
a list of items
type,template,format,total,rot,col,alpha,fontsize,cex,fontfamily,lineheight, andfont- annotations
a list of items
rot,col,alpha,fontsize,cex,fontfamily,lineheight,font, andlabels(a named character vector keyed by subset name). Used to add a third stacked text element per region below the quantity.- strips
col,alpha,fontsize,cex,fontfamily,lineheight, andfont- legend
arguments to
grid::legendGrob()as well ascol,alpha,fontsize,cex,symbol_size(symbol size multiplier, independent of text size; defaults tocexifNULL),fontfamily,lineheight, andfont- main
arguments to
grid::textGrob()- complement
a list of styling defaults for the container box and its complement label drawn when
euler()is called withcomplement =. Items:fill,alpha,col,lty,lwd,lex,fontsize,cex,font,fontfamily,lineheight. The defaultlty = 2draws the container with a dashed outline.- padding
a
grid::unit()giving the padding between various elements in plots fromplot.euler(), which you can change if you, for instance, want to increase spacing between labels, quantities, and percentages.- composition
a list controlling how
eulergramobjects are arranged when composed via|or/. Contains a singlespacingitem (agrid::unit()) that sets the gap between adjacent plots.
Examples
eulerr_options(edges = list(col = "blue"), fontsize = 10)
eulerr_options(n_threads = 2)