View source: R/extendr-wrappers.R
| max_sets_default | R Documentation |
eunoia accepts before rejecting a spec.
Used by the R-side input validator so the cap is not hardcoded.Default number of sets that eunoia accepts before rejecting a spec.
Used by the R-side input validator so the cap is not hardcoded.
max_sets_default()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.