Learn R Programming

eulerr (version 8.1.0)

max_sets_default: Default number of sets that eunoia accepts before rejecting a spec. Used by the R-side input validator so the cap is not hardcoded.

Description

Default number of sets that eunoia accepts before rejecting a spec. Used by the R-side input validator so the cap is not hardcoded.

Usage

max_sets_default()

Arguments