Learn R Programming

eulerr (version 8.1.0)

max_sets_hard_cap: Absolute upper bound on the number of sets that eunoia can represent in a single diagram. Used by the R-side input validator so the cap is not hardcoded.

Description

Absolute upper bound on the number of sets that eunoia can represent in a single diagram. Used by the R-side input validator so the cap is not hardcoded.

Usage

max_sets_hard_cap()

Arguments