setup_geometry: Compute geometries and label locations

View source: R/setup_geometry.R

setup_geometryR Documentation

Compute geometries and label locations

Description

Compute geometries and label locations

Usage

setup_geometry(
  x,
  fills,
  edges,
  labels,
  quantities,
  annotations,
  n,
  merged_sets,
  placement_opts = NULL,
  do_complement_label = FALSE
)

Arguments

x

an object of class 'euler'

fills

fills

edges

edges

labels

labels

quantities

quantities

n

number of vertices to use to render each ellipse

merged_sets

which sets have been merged?

Value

a list object with slots for the various objects


eulerr documentation built on May 30, 2026, 1:07 a.m.