View source: R/setup_geometry.R
| setup_geometry | R Documentation |
Compute geometries and label locations
setup_geometry(
x,
fills,
edges,
labels,
quantities,
annotations,
n,
merged_sets,
placement_opts = NULL,
do_complement_label = FALSE
)
x |
an object of class 'euler' |
fills |
fills |
edges |
edges |
labels |
labels |
quantities |
quantities |
n |
number of vertices to use to render each ellipse |
merged_sets |
which sets have been merged? |
a list object with slots for the various objects
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.