Learn R Programming

eulerr (version 8.1.0)

venn: Venn diagrams

Description

This function fits Venn diagrams using an interface that is almost identical to euler(). Strictly speaking, Venn diagrams are Euler diagrams where every intersection is visible, regardless of whether or not it is zero. In almost every incarnation of Venn diagrams, however, the areas in the diagram are also non-proportional to the input; this is also the case here.

Usage

venn(combinations, ...)

# S3 method for default venn( combinations, input = c("disjoint", "union"), shape = c("ellipse", "rotated_rectangle"), names = letters[length(combinations)], ... )

# S3 method for table venn(combinations, ...)

# S3 method for data.frame venn( combinations, weights = NULL, by = NULL, sep = "_", factor_names = TRUE, ... )

# S3 method for matrix venn(combinations, ...)

# S3 method for list venn(combinations, ...)

Value

Returns an object of class 'eulerr_venn', 'venn', 'euler' with items

shapes

a data frame of the precomputed shape parameters (one row per set). For shape = "ellipse" the columns are type, h, k, a, b, phi; for shape = "rotated_rectangle" they are type, h, k, width, height, phi.

ellipses

the legacy 5-column data frame (h, k, a, b, phi) — kept for back-compat alongside the canonical shapes slot. Only present for shape = "ellipse".

original.values

set relationships in the input

fitted.values

set relationships in the solution

Arguments

combinations

set relationships as a named numeric vector, matrix, or data.frame (see methods (by class))

...

arguments passed down to other methods

input

type of input: disjoint identities ('disjoint') or unions ('union').

shape

geometric shape used in the diagram, either "ellipse" (the default, supporting up to five sets) or "rotated_rectangle" (supporting up to four sets). Rotated rectangles draw a true four-set Venn diagram in which all 15 regions are visible.

names

a character vector for the names of each set of the same length as 'combinations'. Must not be NULL if combinations is a one-length numeric.

weights

a numeric vector of weights of the same length as the number of rows in combinations.

by

a factor or character matrix to be used in base::by() to split the data.frame or matrix of set combinations

sep

a character to use to separate the dummy-coded factors if there are factor or character vectors in 'combinations'.

factor_names

whether to include factor names when constructing dummy codes

Methods (by class)

  • venn(default): a named numeric vector, with combinations separated by an ampersand, for instance A&B = 10. Missing combinations are treated as being 0.

  • venn(table): A table with max(dim(x)) < 3.

  • venn(data.frame): a data.frame of logicals, binary integers, or factors.

  • venn(matrix): a matrix that can be converted to a data.frame of logicals (as in the description above) via base::as.data.frame.matrix().

  • venn(list): a list of vectors, each vector giving the contents of that set (with no duplicates). Vectors in the list do not need to be named.

See Also

plot.eulerr_venn(), print.eulerr_venn(), euler()

Examples

Run this code
# The trivial version
f1 <- venn(5, names = letters[1:5])
plot(f1)

# Using data (a numeric vector)
f2 <- venn(c(A = 1, "B&C" = 3, "A&D" = 0.3))

# The table method
venn(pain, factor_names = FALSE)

# Using grouping via the 'by' argument through the data.frame method
venn(fruits, by = list(sex, age))


# Using the matrix method
venn(organisms)

# Using weights
venn(organisms, weights = c(10, 20, 5, 4, 8, 9, 2))

# A venn diagram from a list of sample spaces (the list method)
venn(plants[c("erigenia", "solanum", "cynodon")])

Run the code above in your browser using DataLab